import * as tf from '@tensorflow/tfjs';
import { FeatureExtractor, RecognizerParams } from './types';
export declare type SpectrogramCallback = (x: tf.Tensor) => Promise<boolean>;
export interface BrowserFftFeatureExtractorConfig extends RecognizerParams {
    numFramesPerSpectrogram: number;
    suppressionTimeMillis: number;
    spectrogramCallback: SpectrogramCallback;
    columnTruncateLength?: number;
}
export declare class BrowserFftFeatureExtractor implements FeatureExtractor {
    readonly numFramesPerSpectrogram: number;
    readonly sampleRateHz: number;
    readonly fftSize: number;
    readonly columnTruncateLength: number;
    readonly overlapFactor: number;
    protected readonly spectrogramCallback: SpectrogramCallback;
    private stream;
    private audioContextConstructor;
    private audioContext;
    private analyser;
    private tracker;
    private readonly ROTATING_BUFFER_SIZE_MULTIPLIER;
    private freqData;
    private rotatingBufferNumFrames;
    private rotatingBuffer;
    private frameCount;
    private frameIntervalTask;
    private frameDurationMillis;
    private suppressionTimeMillis;
    constructor(config: BrowserFftFeatureExtractorConfig);
    start(samples?: Float32Array): Promise<Float32Array[] | void>;
    private onAudioFrame;
    stop(): Promise<void>;
    setConfig(params: RecognizerParams): void;
    getFeatures(): Float32Array[];
}
export declare function getFrequencyDataFromRotatingBuffer(rotatingBuffer: Float32Array, numFrames: number, fftLength: number, frameCount: number): Float32Array;
export declare function getInputTensorFromFrequencyData(freqData: Float32Array, numFrames: number, fftLength: number, toNormalize?: boolean): tf.Tensor;
export declare class Tracker {
    readonly period: number;
    readonly suppressionTime: number;
    private counter;
    private suppressionOnset;
    constructor(period: number, suppressionPeriod: number);
    tick(): boolean;
    suppress(): void;
}
