import * as tf from '@tensorflow/tfjs';
import { BrowserFftFeatureExtractor } from './browser_fft_extractor';
import { RecognizerCallback, RecognizerParams, SpeechCommandRecognizer, SpeechCommandRecognizerResult, StreamingRecognitionConfig, TransferSpeechCommandRecognizer } from './types';
export declare const BACKGROUND_NOISE_TAG = "_background_noise_";
export declare const UNKNOWN_TAG = "_unknown_";
export declare class BrowserFftSpeechCommandRecognizer implements SpeechCommandRecognizer {
    readonly DEFAULT_MODEL_JSON_URL: string;
    readonly DEFAULT_METADATA_JSON_URL: string;
    private readonly SAMPLE_RATE_HZ;
    private readonly FFT_SIZE;
    private readonly DEFAULT_SUPPRESSION_TIME_MILLIS;
    model: tf.Model;
    readonly parameters: RecognizerParams;
    protected words: string[];
    protected nonBatchInputShape: [number, number, number];
    private elementsPerExample;
    protected audioDataExtractor: BrowserFftFeatureExtractor;
    private transferRecognizers;
    constructor();
    startStreaming(callback: RecognizerCallback, config?: StreamingRecognitionConfig): Promise<void>;
    ensureModelLoaded(): Promise<void>;
    private warmUpModel;
    private ensureMetadataLoaded;
    stopStreaming(): Promise<void>;
    isStreaming(): boolean;
    wordLabels(): string[];
    params(): RecognizerParams;
    modelInputShape(): tf.Shape;
    recognize(input: tf.Tensor | Float32Array): Promise<SpeechCommandRecognizerResult>;
    createTransfer(name: string): TransferSpeechCommandRecognizer;
    private freezeModel;
    private checkInputTensorShape;
}
