import * as tf from '@tensorflow/tfjs';
export declare type FFT_TYPE = 'BROWSER_FFT' | 'SOFT_FFT';
export declare type RecognizerCallback = (result: SpeechCommandRecognizerResult) => Promise<void>;
export interface SpeechCommandRecognizer {
    ensureModelLoaded(): Promise<void>;
    startStreaming(callback: RecognizerCallback, config?: StreamingRecognitionConfig): Promise<void>;
    stopStreaming(): Promise<void>;
    isStreaming(): boolean;
    recognize(input: tf.Tensor | Float32Array): Promise<SpeechCommandRecognizerResult>;
    modelInputShape(): tf.Shape;
    wordLabels(): string[];
    params(): RecognizerParams;
    createTransfer(name: string): TransferSpeechCommandRecognizer;
}
export interface TransferSpeechCommandRecognizer extends SpeechCommandRecognizer {
    collectExample(word: string): Promise<SpectrogramData>;
    clearExamples(): void;
    countExamples(): {
        [word: string]: number;
    };
    train(config?: TransferLearnConfig): Promise<tf.History>;
}
export interface SpectrogramData {
    data: Float32Array;
    frameSize: number;
}
export interface SpeechCommandRecognizerResult {
    scores: Float32Array | Float32Array[];
    spectrogram?: SpectrogramData;
}
export interface StreamingRecognitionConfig {
    overlapFactor?: number;
    minSamples?: number;
    suppressionTimeMillis?: number;
    probabilityThreshold?: number;
    invokeCallbackOnNoiseAndUnknown?: boolean;
    includeSpectrogram?: boolean;
}
export interface TransferLearnConfig {
    epochs?: number;
    optimizer?: string | tf.Optimizer;
    batchSize?: number;
    validationSplit?: number;
    callback?: tf.CustomCallbackConfig;
}
export interface RecognizerParams {
    columnBufferLength?: number;
    columnHopLength?: number;
    spectrogramDurationMillis?: number;
    fftSize?: number;
    filterSize?: number;
    sampleRateHz?: number;
}
export interface FeatureExtractor {
    setConfig(params: RecognizerParams): void;
    start(samples?: Float32Array): Promise<Float32Array[] | void>;
    stop(): Promise<void>;
    getFeatures(): Float32Array[];
}
